@@ -47,8 +47,15 @@ class ATCTToolXMLAdapter(XMLAdapterBase, PropertyManagerHelpers):
             node.setAttribute('description', value.description)
             node.setAttribute('enabled', value.enabled and 'True' or 'False')
             for criterion in value.criteria:
+                if isinstance(criterion, dict):
+                    name = criterion['name']
+                    description = criterion['description']
+                else:
+                    name = criterion
+                    description = ''
                 sub = self._doc.createElement('criterion')
-                sub.setAttribute('name', criterion)
+                sub.setAttribute('name', name)
+                sub.setAttribute('description', description)
                 node.appendChild(sub)
             fragment.appendChild(node)
         return fragment
